program checkresults

!This is a short fortran 90 routine to test the output of backcorr

  use param
  use dal
  use errorhandling

  implicit none

  type( DataSetT ) :: Ts_Set
  type( TableT ) :: Table1
  type( ColumnT ) :: Col_Channel, Col_Counts
  integer(kind=int16),dimension(:),pointer :: Array_Channel, Net_Channel
  integer(kind=int32),dimension(:),pointer :: Net_Counts, Array_Counts
  character(len=81)   :: error_message
  integer :: errors

!Read the output dataset in - at the moment it has the filename 
!outbkgspectrum.ds hardwired into the code.

  Ts_Set = dataSet('outbkgspectrum.ds',READ)
  Table1 = table(Ts_Set,BlockNumber(Ts_Set,'SPECTRUM')) 

  Col_Channel = Column(Table1, ColumnNumber(Table1,'CHANNEL'),Read)
  Col_Counts = Column(Table1, ColumnNumber(Table1,'COUNTS'),Read)
  Array_Channel => int16Data(Col_Channel)
  Array_Counts => int32Data(Col_Counts)
  allocate(Net_Channel(size(Array_Channel(:))))
  allocate(Net_Counts(size(Array_Counts(:))))
  Net_Channel = Array_Channel
  Net_Counts = Array_Counts

  errors=0

!Check that the size of the output columns are the same and that they are 
!non-zero

  if (size(Net_Channel(:)) /= size(Net_Counts(:)) .or. size(Net_Channel(:)) &
                     < 1)  errors = errors + 1

!Check to see that relevant header information is included

  if ( .not. HasAttribute(Ts_Set,"RA_OBJ")) errors = errors + 1
  if ( .not. HasAttribute(Ts_Set,"OBJECT")) errors = errors + 1
  if ( .not. HasAttribute(Ts_Set,"EXP_ID")) errors = errors + 1

!Indicate if there are any problems with the file.

  write(error_message,*) 'Detected ',errors,' errors in outbkgspectrum.ds'
  if (errors > 0) call error("test failed",error_message)

end program checkresults
